Module git_auto_commit

Module git_auto_commit 

Auto-commit edited files after each agent turn.

When config.auto_commit is enabled and the working directory is a git repo, files edited during the turn are staged and committed with an auto-generated message.

Enums

AutoCommitOutcome

Functions

auto_commit_edited_files
Auto-commit files edited during the agent turn.