Module truncate

Module truncate 

Functions

post_process_tool_results
Apply truncation to all tool result messages in the last tool_count messages of the conversation.
truncate_output
Dispatch to per-tool truncation based on tool name, then enforce universal upper bounds.