pub struct WorktreeManager { /* private fields */ }Implementations
Sourceimpl WorktreeManager
impl WorktreeManager
pub fn new(repo_root: PathBuf) -> Self
pub fn from_dir(dir: PathBuf) -> Result<Self>
Sourcepub fn create(&self, branch: &str, base: &str) -> Result<Worktree>
pub fn create(&self, branch: &str, base: &str) -> Result<Worktree>
Create a new worktree with a new branch based on base.
Sourcepub fn list(&self) -> Result<Vec<(String, PathBuf, bool)>>
pub fn list(&self) -> Result<Vec<(String, PathBuf, bool)>>
List all worktrees with branch name, path, and change status.
Sourcepub fn remove(&self, branch: &str, force: bool) -> Result<()>
pub fn remove(&self, branch: &str, force: bool) -> Result<()>
Remove a worktree by branch name. Fails if there are uncommitted changes (use force).
pub fn worktree_path(&self, branch: &str) -> PathBuf
pub fn find_worktree_path(&self, branch: &str) -> Result<Option<PathBuf>>
pub fn repo_root(&self) -> &Path