pub fn add_marketplace(url: &str) -> Result<MarketplaceInfo>Expand description
Clone a marketplace, parse its manifest, and persist registration. Caller is responsible for showing UX (spinner). This call blocks on git.
pub fn add_marketplace(url: &str) -> Result<MarketplaceInfo>Clone a marketplace, parse its manifest, and persist registration. Caller is responsible for showing UX (spinner). This call blocks on git.