ensure_seeds_extracted

Function ensure_seeds_extracted 

pub fn ensure_seeds_extracted(cache_root: &Path) -> Result<PathBuf>
Returns the path to the extracted seeds directory. Extracts on first call.

Cache key uses a hash of the embedded tar.zst content (not just CARGO_PKG_VERSION) so that rebuilding with updated seeds (same version number) correctly invalidates the cache. This prevents stale seed files from being served after a rebuild.