Diagnostics tool — surfaces real-time compiler/linter diagnostics from the Language Server without running a full build.
Diagnostics tool — surfaces real-time compiler/linter diagnostics from the Language Server without running a full build.