Module result_store

Module result_store 

Structs

ToolResultRef
A lightweight reference to a tool result whose full output lives on disk. Stored in conversation messages instead of the full output to save memory/tokens.
ToolResultStore
Content-addressed disk cache for tool result outputs.