Auto-commit edited files after each agent turn.
When config.auto_commit is enabled and the working directory is a git repo,
files edited during the turn are staged and committed with an auto-generated message.
Enums
Functions
- auto_
commit_ edited_ files - Auto-commit files edited during the agent turn.