Lightweight git checkpoints for edit rollback.
Uses git stash create to snapshot the working tree WITHOUT modifying
the stash list or working tree. Rollback via git stash apply <ref>.
Functions
- create_
checkpoint - Create a checkpoint. Returns SHA if there are uncommitted changes, None if clean.